==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ZscalerbyzApplicationSettingsApplication.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Zscaler app instance properties
 */
@ApiModel(description = "Zscaler app instance properties")
@JsonPropertyOrder({ ZscalerbyzApplicationSettingsApplication.JSON_PROPERTY_SITE_DOMAIN })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ZscalerbyzApplicationSettingsApplication implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SITE_DOMAIN = "siteDomain";
    private String siteDomain;

    public ZscalerbyzApplicationSettingsApplication() {
    }

    public ZscalerbyzApplicationSettingsApplication siteDomain(String siteDomain) {

        this.siteDomain = siteDomain;
        return this;
    }

    /**
     * Your Zscaler domain
     *
     * @return siteDomain
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Your Zscaler domain")
    @JsonProperty(JSON_PROPERTY_SITE_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSiteDomain() {
        return siteDomain;
    }

    @JsonProperty(JSON_PROPERTY_SITE_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSiteDomain(String siteDomain) {
        this.siteDomain = siteDomain;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ZscalerbyzApplicationSettingsApplication zscalerbyzApplicationSettingsApplication = (ZscalerbyzApplicationSettingsApplication) o;
        return Objects.equals(this.siteDomain, zscalerbyzApplicationSettingsApplication.siteDomain);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(siteDomain);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ZscalerbyzApplicationSettingsApplication {\n");
        sb.append("    siteDomain: ").append(toIndentedString(siteDomain)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ZscalerbyzApplicationSettingsApplication.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Zscaler app instance properties
 */
@ApiModel(description = "Zscaler app instance properties")
@JsonPropertyOrder({ ZscalerbyzApplicationSettingsApplication.JSON_PROPERTY_SITE_DOMAIN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class ZscalerbyzApplicationSettingsApplication implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SITE_DOMAIN = "siteDomain";
    private String siteDomain;

    public ZscalerbyzApplicationSettingsApplication() {
    }

    public ZscalerbyzApplicationSettingsApplication siteDomain(String siteDomain) {

        this.siteDomain = siteDomain;
        return this;
    }

    /**
     * Your Zscaler domain
     *
     * @return siteDomain
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Your Zscaler domain")
    @JsonProperty(JSON_PROPERTY_SITE_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSiteDomain() {
        return siteDomain;
    }

    @JsonProperty(JSON_PROPERTY_SITE_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSiteDomain(String siteDomain) {
        this.siteDomain = siteDomain;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ZscalerbyzApplicationSettingsApplication zscalerbyzApplicationSettingsApplication = (ZscalerbyzApplicationSettingsApplication) o;
        return Objects.equals(this.siteDomain, zscalerbyzApplicationSettingsApplication.siteDomain);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(siteDomain);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ZscalerbyzApplicationSettingsApplication {\n");
        sb.append("    siteDomain: ").append(toIndentedString(siteDomain)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
